#
# spec file for package rpm-ndb
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!_fillupdir:%define _fillupdir /var/adm/fillup-templates}

%global without_bdb 1
Name:           rpm-ndb
Version:        4.14.3
Release:        43.1
Summary:        The RPM Package Manager, ndb only version
License:        GPL-2.0-or-later
Group:          System/Packages
Source99:       rpm.spec
BuildRequires:  binutils
BuildRequires:  bzip2
BuildRequires:  file-devel
BuildRequires:  findutils
BuildRequires:  gcc
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  gzip
BuildRequires:  libacl-devel
BuildRequires:  libbz2-devel
BuildRequires:  libcap-devel
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  libselinux-devel
BuildRequires:  libsemanage-devel
BuildRequires:  libtool
BuildRequires:  lua-devel
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  patch
BuildRequires:  perl-base
BuildRequires:  popt-devel
BuildRequires:  rpm-build
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
%if 0%{?sle_version} >= 150200
BuildRequires:  libgcrypt-devel
BuildRequires:  libzstd-devel
%endif
%if 0%{?is_opensuse}
ExclusiveArch:	not_needed_for_opensuse
%endif
#!BuildIgnore:  rpmlint-Factory
Provides:       rpminst
Provides:       rpm = %{version}-%{release}
Conflicts:      rpm
Requires(post): %fillup_prereq
Requires:       rpm-config-SUSE
%{expand:%(sed -n -e '/^Source:/,/^BuildRoot:/p' <%{_sourcedir}/rpm.spec)}
#
# avoid bootstrapping problem
%define _binary_payload w9.bzdio

%description
RPM Package Manager is the main tool for managing the software packages
of the SUSE Linux distribution.

RPM can be used to install and remove software packages. With rpm, it
is easy to update packages.  RPM keeps track of all these manipulations
in a central database.  This way it is possible to get an overview of
all installed packages.  RPM also supports database queries.

%prep
%{expand:%(sed -n -e '/^%%prep/,/^%%install/p' <%{_sourcedir}/rpm.spec | sed -e '1d' -e '$d')}

%install
%{expand:%(sed -n -e '/^%%install/,/^%%post/p' <%{_sourcedir}/rpm.spec | sed -e '1d' -e '$d')}
sed -i -e '/_db_backend/s/bdb/ndb/' %{buildroot}/usr/lib/rpm/macros
# we use rpm-devel and rpm-build subpackages from original rpm
rm -f %{buildroot}/usr/bin/rpmbuild
rm -rf %{buildroot}/usr/include/rpm
rm -f %{buildroot}%{_libdir}/*.so
rm -rf %{buildroot}%{_libdir}/pkgconfig

%pre
if test -f usr/lib/sysimage/rpm/Packages -a ! -f usr/lib/sysimage/rpm/Packages.db ; then
  echo "Rpm database uses Berkeley DB, cannot install rpm-ndb"
  exit 1
fi

%post
%{fillup_only -an services}
test -f usr/lib/sysimage/rpm/Packages -o -f usr/lib/sysimage/rpm/Packages.db || rpmdb --initdb

%files -f rpm.lang
%defattr(-,root,root)
%license        COPYING
%doc    doc/manual
%doc    RPM-HOWTO
        /etc/rpm
        /bin/rpm
        /usr/bin/*
        /usr/sbin/rpmconfigcheck
        /usr/lib/systemd/system/rpmconfigcheck.service
        /usr/lib/rpm
        %{_libdir}/rpm-plugins
        %{_libdir}/librpm.so.*
        %{_libdir}/librpmbuild.so.*
        %{_libdir}/librpmio.so.*
        %{_libdir}/librpmsign.so.*
%doc    %{_mandir}/man[18]/*.[18]*
%dir    /usr/lib/sysimage
%dir    /usr/lib/sysimage/rpm
%dir    /var/lib/rpm
%dir    %attr(755,root,root) /usr/src/packages/BUILD
%dir    %attr(755,root,root) /usr/src/packages/SPECS
%dir    %attr(755,root,root) /usr/src/packages/SOURCES
%dir    %attr(755,root,root) /usr/src/packages/SRPMS
%dir    %attr(755,root,root) /usr/src/packages/RPMS
%dir    %attr(755,root,root) /usr/src/packages/BUILDROOT
%dir    %attr(755,root,root) /usr/src/packages/RPMS/*
        %{_fillupdir}/sysconfig.services-rpm

%changelog
* Wed Apr 14 2021 ngompa13@gmail.com
- update to rpm-4.14.3
* Thu Jan 16 2020 mls@suse.de
- Initial revision
